# Builder plugins

-----

See the documentation for [build configuration](../../config/build.md).

::: hatchling.builders.plugin.interface.BuilderInterface
    options:
      members:
      - PLUGIN_NAME
      - app
      - root
      - build_config
      - target_config
      - config
      - get_config_class
      - get_version_api
      - get_default_versions
      - clean
      - recurse_included_files
      - get_default_build_data
